@@ -26,4 +26,10 @@
      * BasePower /1./
        data
      * CutOffFile /' '/ 
+       data
+     * UserHookc/MAX_USERHOOKC*' '/
+       data
+     * UserHooki/MAX_USERHOOKI*99999999/
+       data
+     * UserHookr/MAX_USERHOOKR*1.d65/
       end
