@@ -86,7 +86,7 @@ c
 c
        record /ptcl/ pj, tg,  a(*)
        integer ntp, icon, jcon, nfin
-       integer i
+       integer i, outc
        record /ptcl/ pjin
 c         use pt=0 incident
       pjin = pj
@@ -116,19 +116,24 @@ c           ptcls in 'a' should have cms energy, here.
 c           give final ptcl charge/ subcode for 
 c           pi+-,  k0,k0~,k+,k-
       call cpikcd(a, ntp)
+      outc =Rtglab.charge+Rpjlab.charge - pj.charge- tg.charge
+      call cconsvChg(outc, a, ntp, icon)
+      if(icon .eq. 0) then
 c              boost  to lab system
-      do   i=1, ntp
-         call cibst1(i, Cmsp, a(i), a(i))
-      enddo
+         do   i=1, ntp
+            call cibst1(i, Cmsp, a(i), a(i))
+         enddo
 c          decay of "composit ptcls" (nn~, dd~)
-      call cdcycp(a, ntp, nfin)
-      ntp=nfin
+         call cdcycp(a, ntp, nfin)
+         ntp=nfin
 c            store recoils in a
-      a(ntp+1) = Rtglab
-      a(ntp+2) = Rpjlab
-      ntp = ntp +2
-c       -------------- rotate 
-      call crot3mom(pj, a, ntp)
+         a(ntp+1) = Rtglab
+         a(ntp+2) = Rpjlab
+         ntp = ntp +2
+c     -------------- rotate 
+         call crot3mom(pj, a, ntp)
+      endif
+
       end
 c      ****************************************************
 c           decay of nn~  or  DD~ in the projectile system
