@@ -508,7 +508,7 @@ c---------kinematical tests---------------------------------------------
           pa3=(0.5*x3*w)**2-zmmass**2
           pa2=0.5*(2.-x1-x3)*w
 
-          if(pa1.lt.0.0.or.pa3.lt.0.0) then
+          if(pa1 .le.0.0 .or. pa3 .le. 0.0  .or. pa2 .le. 0.) then
             iflag=1
             goto 13
           endif
