@@ -9,8 +9,11 @@ c	(->	---------------------------------------------------
                         !   "ps" is for point source (See also SourceDec)
                         !   "aps" is around point source (See also SourceDec and  Ddelta) 
            real*8  SourceDec    !1  Source declination of point source.(deg)
-	   real*8  Ddelta       !1  SourceDec +- Ddelta is the region for 'aps' (deg).
+	   real*8  Ddelta       !1  SourceDec $\pm$ Ddelta is the region for 'aps' (deg).
            real*8  HeightOfInj  !1  The vertical height of primary injection point (m).
+                                !   If this is $<$ deepest obs. level and zeinth angle of primary is $< 0$, 
+                                !   the primary is  assumed to be upgoing even if Reverse =0.
+	                        !   NOTE: BorderHeightH must be given explicitly in this case.
 	   real*8  OffsetHeight !2  The vertical offset  height from  the deepest detector. 
                                 ! The  primary is directed to this height above the detector.
 
