@@ -29,6 +29,8 @@ c
 c       ************************* see if geomagnetic cut or not.
         subroutine cifCutOff(icon)
         implicit none
+#include "Zobs.h"
+#include "Zobsp.h"
 #include "Ztrack.h"
 #include "ZrigCut.h"
 
@@ -51,6 +53,13 @@ c            angleatOb is down going ptcl's one, change sign
 c             convert to theta fai in deg
             call kdir2deg(angleatOb.r(1), angleatOb.r(2),
      *      angleatOb.r(3), theta, azm)
+c
+c               azm is given from the current x-axis  (+ is counter
+c              clock wise) The x-axis is XaxisFromSouth
+c            degrees from the south in counter clockwise.
+c            convert azm so that measured from the south
+c
+            azm = azm+ XaxisFromSouth
             if(ZenValue .eq. 'cos') then
 c                table zenith is in cos
                zen = angleatOb.r(3)
